@@ -4,8 +4,8 @@ import numpy as np
 
 from supermercado import super_utils as sutils
 
-def findedges(inputtiles, parsenames):
 
+def findedges(inputtiles, parsenames):
 
     tiles = sutils.tile_parser(inputtiles, parsenames)
 
@@ -21,9 +21,12 @@ def findedges(inputtiles, parsenames):
     idxs = sutils.get_idx()
 
     # Using the indices to roll + stack the array, find the minimum along the rolled / stacked axis
-    xys_edge = (np.min(np.dstack((
-        np.roll(np.roll(burn, i[0], 0), i[1], 1) for i in idxs
-        )), axis=2) - burn)
+    xys_edge = (
+        np.min(
+            np.dstack([np.roll(np.roll(burn, i[0], 0), i[1], 1) for i in idxs]), axis=2
+        )
+        ^ burn
+    )
 
     # Set missed non-tiles to False
     xys_edge[burn == False] = False
@@ -35,8 +38,10 @@ def findedges(inputtiles, parsenames):
 
     # Return the edge array
 
-    return np.append(xys_edge, np.zeros((xys_edge.shape[0], 1), dtype=np.uint8) + zoom, axis=1)
+    return np.append(
+        xys_edge, np.zeros((xys_edge.shape[0], 1), dtype=np.uint8) + zoom, axis=1
+    )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     findedges()
