@@ -21,22 +21,32 @@ def union(inputtiles, parsenames):
 
     se = mercantile.xy(*mercantile.ul(xmax + 1, ymax + 1, zoom))
 
-    aff = Affine(((se[0] - nw[0]) / float(xmax - xmin + 1)), 0.0, nw[0],
-        0.0, -((nw[1] - se[1]) / float(ymax - ymin + 1)), nw[1])
+    aff = Affine(
+        ((se[0] - nw[0]) / float(xmax - xmin + 1)),
+        0.0,
+        nw[0],
+        0.0,
+        -((nw[1] - se[1]) / float(ymax - ymin + 1)),
+        nw[1],
+    )
 
     unprojecter = sutils.Unprojecter()
 
     unionedTiles = [
         {
-            'geometry': unprojecter.unproject(feature),
-            'properties': {},
-            'type': 'Feature'
-        } for feature, shapes in features.shapes(np.asarray(np.flipud(np.rot90(burn)).astype(np.uint8), order='C'), transform=aff) if shapes == 1
+            "geometry": unprojecter.unproject(feature),
+            "properties": {},
+            "type": "Feature",
+        }
+        for feature, shapes in features.shapes(
+            np.asarray(np.flipud(np.rot90(burn)).astype(np.uint8), order="C"),
+            transform=aff,
+        )
+        if shapes == 1
     ]
 
     return unionedTiles
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     union()
-
